@@ -2,7 +2,7 @@ import numpy
 import xarray
 import matplotlib.pyplot as plt
 
-class plotshow():
+class objearth():
     def __init__(self,DataArray,lst=True):
         self.DataArray = DataArray
         self.lst=lst
